Clojure only.

tmducken.duckdb.ffi


appender-def*clj


blob-def*clj


column-def*clj


data-chunk-def*clj


define-datatypes!clj

(define-datatypes!)

define-long-enumscljmacro

(define-long-enums)

duckdb-type-mapclj


duckdb_append_data_chunkclj

(duckdb_append_data_chunk appender data-chunk)

No documentation!

No documentation!
raw docstring

duckdb_appender_createclj

(duckdb_appender_create connection schema table out_appender)

No documentation!

No documentation!
raw docstring

duckdb_appender_destroyclj

(duckdb_appender_destroy appender)

Close the appender and destroy it. Flushing all intermediate state in the appender to the table, and de-allocating all memory associated with the appender.

  • appender: The appender to flush, close and destroy.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Close the appender and destroy it. Flushing all intermediate state in the appender to the table, and de-allocating
all memory associated with the appender.

* appender: The appender to flush, close and destroy.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

duckdb_appender_error_dataclj

(duckdb_appender_error_data appender)

Returns the error data associated with the given appender.

The result must be destroyed with duckdb_destroy_error_data.

  • appender: The appender to get the error data from.
  • returns: The error data.
Returns the error data associated with the given appender.

The result must be destroyed with `duckdb_destroy_error_data`.

* appender: The appender to get the error data from.
* returns: The error data.
raw docstring

duckdb_bind_booleanclj

(duckdb_bind_boolean prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_dateclj

(duckdb_bind_date prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_doubleclj

(duckdb_bind_double prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_floatclj

(duckdb_bind_float prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_int16clj

(duckdb_bind_int16 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_int32clj

(duckdb_bind_int32 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_int64clj

(duckdb_bind_int64 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_int8clj

(duckdb_bind_int8 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_nullclj

(duckdb_bind_null prepared-statement param-idx)

No documentation!

No documentation!
raw docstring

duckdb_bind_timeclj

(duckdb_bind_time prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_timestampclj

(duckdb_bind_timestamp prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_uint16clj

(duckdb_bind_uint16 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_uint32clj

(duckdb_bind_uint32 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_uint64clj

(duckdb_bind_uint64 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_uint8clj

(duckdb_bind_uint8 prepared-statement param-idx val)

No documentation!

No documentation!
raw docstring

duckdb_bind_varchar_lengthclj

(duckdb_bind_varchar_length prepared-statement param-idx val length)

No documentation!

No documentation!
raw docstring

duckdb_clear_bindingsclj

(duckdb_clear_bindings prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_closeclj

(duckdb_close database)

Closes the specified database and de-allocates all memory allocated for that database. This should be called after you are done with any database allocated through duckdb_open. Note that failing to call duckdb_close (in case of e.g. a program crash) will not cause data corruption. Still it is recommended to always correctly close a database object after you are done with it.

  • database: The database object to shut down.
Closes the specified database and de-allocates all memory allocated for that database.
This should be called after you are done with any database allocated through `duckdb_open`.
Note that failing to call `duckdb_close` (in case of e.g. a program crash) will not cause data corruption.
Still it is recommended to always correctly close a database object after you are done with it.

* database: The database object to shut down.
raw docstring

duckdb_column_countclj

(duckdb_column_count result)

No documentation!

No documentation!
raw docstring

duckdb_column_logical_typeclj

(duckdb_column_logical_type result cidx)

No documentation!

No documentation!
raw docstring

duckdb_column_nameclj

(duckdb_column_name result col)

No documentation!

No documentation!
raw docstring

duckdb_column_typeclj

(duckdb_column_type result col)

No documentation!

No documentation!
raw docstring

duckdb_config_countclj

(duckdb_config_count)

This returns the total amount of configuration options available for usage with duckdb_get_config_flag.

This should not be called in a loop as it internally loops over all the options.

  • returns: The amount of config options available.
This returns the total amount of configuration options available for usage with `duckdb_get_config_flag`.

This should not be called in a loop as it internally loops over all the options.

* returns: The amount of config options available.
raw docstring

duckdb_connectclj

(duckdb_connect database out_connection)

Opens a connection to a database. Connections are required to query the database, and store transactional state associated with the connection.

  • database: The database file to connect to.
  • out_connection: The result connection object.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Opens a connection to a database. Connections are required to query the database, and store transactional state
associated with the connection.

* database: The database file to connect to.
* out_connection: The result connection object.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

duckdb_create_configclj

(duckdb_create_config out_config)

Initializes an empty configuration object that can be used to provide start-up options for the DuckDB instance through duckdb_open_ext.

This will always succeed unless there is a malloc failure.

  • out_config: The result configuration object.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Initializes an empty configuration object that can be used to provide start-up options for the DuckDB instance
through `duckdb_open_ext`.

This will always succeed unless there is a malloc failure.

* out_config: The result configuration object.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

duckdb_create_data_chunkclj

(duckdb_create_data_chunk types column-count)

No documentation!

No documentation!
raw docstring

duckdb_create_logical_typeclj

(duckdb_create_logical_type duckdb_type)

No documentation!

No documentation!
raw docstring

duckdb_data_chunk_get_column_countclj

(duckdb_data_chunk_get_column_count chunk)

No documentation!

No documentation!
raw docstring

duckdb_data_chunk_get_sizeclj

(duckdb_data_chunk_get_size chunk)

No documentation!

No documentation!
raw docstring

duckdb_data_chunk_get_vectorclj

(duckdb_data_chunk_get_vector chunk col-idx)

No documentation!

No documentation!
raw docstring

duckdb_data_chunk_resetclj

(duckdb_data_chunk_reset chunk)

No documentation!

No documentation!
raw docstring

duckdb_data_chunk_set_sizeclj

(duckdb_data_chunk_set_size chunk size)

No documentation!

No documentation!
raw docstring

duckdb_destroy_configclj

(duckdb_destroy_config config)

Destroys the specified configuration option and de-allocates all memory allocated for the object.

  • config: The configuration object to destroy.
Destroys the specified configuration option and de-allocates all memory allocated for the object.

* config: The configuration object to destroy.
raw docstring

duckdb_destroy_data_chunkclj

(duckdb_destroy_data_chunk chunk)

No documentation!

No documentation!
raw docstring

duckdb_destroy_error_dataclj

(duckdb_destroy_error_data error-data)

No documentation!

No documentation!
raw docstring

duckdb_destroy_extractedclj

(duckdb_destroy_extracted extracted-statements)

No documentation!

No documentation!
raw docstring

duckdb_destroy_logical_typeclj

(duckdb_destroy_logical_type type)

No documentation!

No documentation!
raw docstring

duckdb_destroy_pendingclj

(duckdb_destroy_pending pending-result)

No documentation!

No documentation!
raw docstring

duckdb_destroy_prepareclj

(duckdb_destroy_prepare prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_destroy_resultclj

(duckdb_destroy_result result)

No documentation!

No documentation!
raw docstring

duckdb_disconnectclj

(duckdb_disconnect connection)

Closes the specified connection and de-allocates all memory allocated for that connection.

  • connection: The connection to close.
Closes the specified connection and de-allocates all memory allocated for that connection.

* connection: The connection to close.
raw docstring

duckdb_error_data_messageclj

(duckdb_error_data_message error-data)

Returns the error message of the error data. Must not be freed - it is de-allocated along with the error data.

Returns the error message of the error data.  Must not be freed - it is
de-allocated along with the error data.
raw docstring

duckdb_execute_pendingclj

(duckdb_execute_pending pending-result duckdb-result)

No documentation!

No documentation!
raw docstring

duckdb_extract_statementsclj

(duckdb_extract_statements connection query out-extracted-statements)

No documentation!

No documentation!
raw docstring

duckdb_extract_statements_errorclj

(duckdb_extract_statements_error statements)

No documentation!

No documentation!
raw docstring

duckdb_fetch_chunkclj

(duckdb_fetch_chunk result)

Fetches a data chunk from a duckdb_result, returning nil once the result is exhausted. Works for both streaming and materialized results. Supersedes duckdb_stream_fetch_chunk.

Fetches a data chunk from a duckdb_result, returning nil once the result is
exhausted.  Works for both streaming and materialized results.  Supersedes
`duckdb_stream_fetch_chunk`.
raw docstring

duckdb_freeclj

(duckdb_free ptr)

No documentation!

No documentation!
raw docstring

duckdb_get_config_flagclj

(duckdb_get_config_flag index out_name out_description)

Obtains a human-readable name and description of a specific configuration option. This can be used to e.g. display configuration options. This will succeed unless index is out of range (i.e. >= duckdb_config_count).

The result name or description MUST NOT be freed.

  • index: The index of the configuration option (between 0 and duckdb_config_count)
  • out_name: A name of the configuration flag.
  • out_description: A description of the configuration flag.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Obtains a human-readable name and description of a specific configuration option. This can be used to e.g.
display configuration options. This will succeed unless `index` is out of range (i.e. `>= duckdb_config_count`).

The result name or description MUST NOT be freed.

* index: The index of the configuration option (between 0 and `duckdb_config_count`)
* out_name: A name of the configuration flag.
* out_description: A description of the configuration flag.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

duckdb_get_type_idclj

(duckdb_get_type_id type)

No documentation!

No documentation!
raw docstring

duckdb_library_versionclj

(duckdb_library_version)

No documentation!

No documentation!
raw docstring

duckdb_list_type_child_typeclj

(duckdb_list_type_child_type type)

No documentation!

No documentation!
raw docstring

duckdb_list_vector_get_childclj

(duckdb_list_vector_get_child vector)

No documentation!

No documentation!
raw docstring

duckdb_list_vector_get_sizeclj

(duckdb_list_vector_get_size vector)

No documentation!

No documentation!
raw docstring

duckdb_mallocclj

(duckdb_malloc size)

No documentation!

No documentation!
raw docstring

duckdb_nparamsclj

(duckdb_nparams prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_openclj

(duckdb_open path out_database)

Creates a new database or opens an existing database file stored at the the given path. If no path is given a new in-memory database is created instead.

  • path: Path to the database file on disk, or nullptr or :memory: to open an in-memory database.
  • out_database: The result database object.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Creates a new database or opens an existing database file stored at the the given path.
If no path is given a new in-memory database is created instead.

* path: Path to the database file on disk, or `nullptr` or `:memory:` to open an in-memory database.
* out_database: The result database object.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

duckdb_open_extclj

(duckdb_open_ext path out_database config out_error)

No documentation!

No documentation!
raw docstring

duckdb_param_typeclj

(duckdb_param_type prepared-statement param-idx)

No documentation!

No documentation!
raw docstring

duckdb_pending_errorclj

(duckdb_pending_error pending-result)

No documentation!

No documentation!
raw docstring

duckdb_pending_preparedclj

(duckdb_pending_prepared prepared-statement out-pending-result)

No documentation!

No documentation!
raw docstring

duckdb_pending_prepared_streamingclj

(duckdb_pending_prepared_streaming prepared-statement out-pending-result)

No documentation!

No documentation!
raw docstring

duckdb_prepareclj

(duckdb_prepare connection query out-prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_prepare_errorclj

(duckdb_prepare_error prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_prepare_extracted_statementclj

(duckdb_prepare_extracted_statement connection
                                    statement
                                    statement-idx
                                    out-prepared-statement)

No documentation!

No documentation!
raw docstring

duckdb_prepared_statement_typeclj

(duckdb_prepared_statement_type statement)

No documentation!

No documentation!
raw docstring

duckdb_queryclj

(duckdb_query connection query out_result)

No documentation!

No documentation!
raw docstring

duckdb_result_chunk_countclj

(duckdb_result_chunk_count result)

No documentation!

No documentation!
raw docstring

duckdb_result_errorclj

(duckdb_result_error result)

Returns the error message contained within the result, or nil if the result did not error. Must not be freed - it is de-allocated by duckdb_destroy_result.

Returns the error message contained within the result, or nil if the result
did not error.  Must not be freed - it is de-allocated by `duckdb_destroy_result`.
raw docstring

duckdb_result_get_chunkclj

(duckdb_result_get_chunk result chunk-index)

No documentation!

No documentation!
raw docstring

duckdb_result_return_typeclj

(duckdb_result_return_type result)

No documentation!

No documentation!
raw docstring

duckdb_result_statement_typeclj

(duckdb_result_statement_type result)

No documentation!

No documentation!
raw docstring

duckdb_set_configclj

(duckdb_set_config config name option)

Sets the specified option for the specified configuration. The configuration option is indicated by name. To obtain a list of config options, see duckdb_get_config_flag.

In the source code, configuration options are defined in config.cpp.

This can fail if either the name is invalid, or if the value provided for the option is invalid.

  • duckdb_config: The configuration object to set the option on.
  • name: The name of the configuration flag to set.
  • option: The value to set the configuration flag to.
  • returns: DuckDBSuccess on success or DuckDBError on failure.
Sets the specified option for the specified configuration. The configuration option is indicated by name.
To obtain a list of config options, see `duckdb_get_config_flag`.

In the source code, configuration options are defined in `config.cpp`.

This can fail if either the name is invalid, or if the value provided for the option is invalid.

* duckdb_config: The configuration object to set the option on.
* name: The name of the configuration flag to set.
* option: The value to set the configuration flag to.
* returns: `DuckDBSuccess` on success or `DuckDBError` on failure.
raw docstring

DUCKDB_TYPE_ANYclj


DUCKDB_TYPE_ARRAYclj


DUCKDB_TYPE_BIGINTclj


DUCKDB_TYPE_BIGNUMclj


DUCKDB_TYPE_BITclj


DUCKDB_TYPE_BLOBclj


DUCKDB_TYPE_BOOLEANclj


DUCKDB_TYPE_DATEclj


DUCKDB_TYPE_DECIMALclj


DUCKDB_TYPE_DOUBLEclj


DUCKDB_TYPE_ENUMclj


DUCKDB_TYPE_FLOATclj


DUCKDB_TYPE_GEOMETRYclj


DUCKDB_TYPE_HUGEINTclj


DUCKDB_TYPE_INTEGERclj


DUCKDB_TYPE_INTEGER_LITERALclj


DUCKDB_TYPE_INTERVALclj


DUCKDB_TYPE_INVALIDclj


DUCKDB_TYPE_LISTclj


DUCKDB_TYPE_MAPclj


DUCKDB_TYPE_SMALLINTclj


DUCKDB_TYPE_SQLNULLclj


DUCKDB_TYPE_STRING_LITERALclj


DUCKDB_TYPE_STRUCTclj


DUCKDB_TYPE_TIMEclj


DUCKDB_TYPE_TIME_NSclj


DUCKDB_TYPE_TIME_TZclj


DUCKDB_TYPE_TIMESTAMPclj


DUCKDB_TYPE_TIMESTAMP_MSclj


DUCKDB_TYPE_TIMESTAMP_NSclj


DUCKDB_TYPE_TIMESTAMP_Sclj


DUCKDB_TYPE_TIMESTAMP_TZclj


DUCKDB_TYPE_TINYINTclj


DUCKDB_TYPE_UBIGINTclj


DUCKDB_TYPE_UHUGEINTclj


DUCKDB_TYPE_UINTEGERclj


DUCKDB_TYPE_UNIONclj


DUCKDB_TYPE_USMALLINTclj


DUCKDB_TYPE_UTINYINTclj


DUCKDB_TYPE_UUIDclj


DUCKDB_TYPE_VARCHARclj


DUCKDB_TYPE_VARIANTclj


duckdb_vector_ensure_validity_writableclj

(duckdb_vector_ensure_validity_writable vector)

No documentation!

No documentation!
raw docstring

duckdb_vector_get_column_typeclj

(duckdb_vector_get_column_type vector)

No documentation!

No documentation!
raw docstring

duckdb_vector_get_dataclj

(duckdb_vector_get_data vector)

No documentation!

No documentation!
raw docstring

duckdb_vector_get_validityclj

(duckdb_vector_get_validity vector)

No documentation!

No documentation!
raw docstring

duckdb_vector_sizeclj

(duckdb_vector_size)

No documentation!

No documentation!
raw docstring

DuckDBErrorclj


DuckDBSuccessclj


libclj


lib-fnsclj


lib-symbolsclj


logical-type-def*clj


prepared-statement-def*clj


ptr-dtype*clj


result-def*clj


vector-def*clj

cljdoc builds & hosts documentation for Clojure/Script libraries